@@ -5,12 +5,15 @@ OC.L10N.register(
     "All contacts" : "ყველა კონტაქტი",
     "Contacts" : "კონტაქტები",
     "Loading contacts …" : "კონტაქტების ჩატვირთვა ...",
+    "Delete circle" : "წრის გაუქმება",
     "Download" : "ჩამოტვირთვა",
+    "Send email" : "ელ-წერილის გაგზავნა",
     "Groups" : "ჯგუფები",
     "Group name" : "ჯგუფის სახელი",
+    "Circles" : "წრეები",
+    "Create a new circle" : "შექმენით წრე",
     "Rename" : "სახელის შეცვლა",
     "Enabled" : "მოქმედია",
-    "Disabled" : "არაა მოქმედი",
     "Delete" : "გაუქმება",
     "Copy link" : "ბმულის კოპირება",
     "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
@@ -19,18 +22,32 @@ OC.L10N.register(
     "Last name" : "გვარი",
     "Display name" : "დისპლეი სახელი",
     "Last modified" : "ბოლო ცვლილება",
+    "Password protection" : "პაროლით თავდაცვა",
+    "Save" : "შენახვა",
+    "Description" : "აღწერილობა",
     "Invalid image" : "არასწორი სურათი",
     "Name" : "სახელი",
     "Title" : "სათაური",
     "Cancel" : "უარყოფა",
     "Address book" : "მისამართების წიგნი",
     "New contact" : "ახალი კონტაქტი",
+    "Search contacts …" : "მოძებნეთ კონტაქტები ...",
     "No results" : "შედეგები არაა",
+    "Personal circle" : "პირადი წრე",
+    "Pending" : "მოლოდინში",
     "Close" : "დახურვა",
     "Import" : "იმპორტი",
     "Not grouped" : "არაა დაჯგუფებული",
+    "Circle" : "წრე",
+    "User" : "მომხმარებელი",
+    "Group" : "ჯგუფი",
     "Email" : "ელ-ფოსტა",
     "Contact" : "კონტაქტი",
+    "Member" : "წევრი",
+    "Moderator" : "მოდერატორი",
+    "Admin" : "ადმინისტრატორი",
+    "Owner" : "მფლობელი",
+    "Users" : "მომხმარებლები",
     "Nickname" : "ნიკნეიმი",
     "Detailed name" : "დეტალური სახელი",
     "Additional names" : "დამატებითი სახელები",
@@ -63,6 +80,7 @@ OC.L10N.register(
     "Voice" : "ხმა",
     "Car" : "მაქნანა",
     "Work pager" : "სამუშაო პეიჯერი",
+    "Manager" : "მენეჯერი",
     "Social network" : "სოციალური ქსელი",
     "Spouse" : "მეუღლე",
     "Child" : "შვილი",
@@ -74,7 +92,6 @@ OC.L10N.register(
     "Relative" : "ნათესავი",
     "Friend" : "მეგობარი",
     "Colleague" : "კოლეგა",
-    "Manager" : "მენეჯერი",
     "Assistant" : "ასისტენტი",
     "Gender" : "სქესი",
     "Female" : "მდედორობითი",
